@@ -1,5 +1,5 @@
 import abc
-import os
+import pathlib
 from typing import TYPE_CHECKING, Any, Dict, cast
 
 import yaml
@@ -9,16 +9,13 @@ if TYPE_CHECKING:
 
 
 class _BuddyMetadata(abc.ABC):
-    """Buddy's experiment metadata management interface.
-    """
+    """Buddy's experiment metadata management interface."""
 
     def __init__(self, metadata_dir: str) -> None:
-        """Metadata-specific setup.
-        """
-
-        # Attempt to read existing metadata
+        """Metadata-specific setup."""
         self._metadata_dir = metadata_dir
         try:
+            # Attempt to read existing metadata
             self.load_metadata(_write=True)
         except FileNotFoundError:
             self._metadata: Dict[str, Any] = {}
@@ -40,7 +37,7 @@ class _BuddyMetadata(abc.ABC):
                 experiment_name = cast("Buddy", self)._experiment_name
             if metadata_dir is None:
                 metadata_dir = self._metadata_dir
-            path = os.path.join(metadata_dir, f"{experiment_name}.yaml")
+            path = str(pathlib.Path(metadata_dir) / f"{experiment_name}.yaml")
         else:
             assert experiment_name is None and metadata_dir is None
 
@@ -80,28 +77,27 @@ class _BuddyMetadata(abc.ABC):
 
     def _write_metadata(self) -> None:
         # Create metadata directory if needed
-        if not os.path.isdir(self._metadata_dir):
-            os.makedirs(self._metadata_dir)
-            cast("Buddy", self)._print("Created directory:", self._metadata_dir)
+        metadata_dir = pathlib.Path(self._metadata_dir)
+        assert not metadata_dir.is_file()
+        if not metadata_dir.exists():
+            metadata_dir.mkdir(parents=True)
+            cast("Buddy", self)._print("Created directory:", metadata_dir)
 
         # Write metadata to file
-        metadata_path = "{}/{}.yaml".format(
-            self._metadata_dir, cast("Buddy", self)._experiment_name,
-        )
+        metadata_path = metadata_dir / f"{cast('Buddy', self)._experiment_name}.yaml"
         with open(metadata_path, "w") as file:
             yaml.dump(self._metadata, file, default_flow_style=False)
             cast("Buddy", self)._print("Wrote metadata to:", metadata_path)
 
     @property
     def metadata(self) -> Dict[str, Any]:
-        """Read-only interface for experiment metadata.
-        """
+        """Read-only interface for experiment metadata."""
         return self._metadata
 
     @property
     def metadata_path(self) -> str:
-        """Read-only path to my metadata file.
-        """
-        return os.path.join(
-            self._metadata_dir, f"{cast('Buddy', self)._experiment_name}.yaml"
+        """Read-only path to my metadata file."""
+        return str(
+            pathlib.Path(self._metadata_dir)
+            / f"{cast('Buddy', self)._experiment_name}.yaml"
         )
